@@ -6,5 +6,5 @@ def get_path() -> Path:
     if getattr(sys, "frozen", False):
         file_dir = Path(getattr(sys, "_MEIPASS"))
     else:
-        file_dir = Path(__file__).parent
-    return file_dir
+        file_dir = Path(__file__).parent.parent
+    return file_dir.joinpath("pre_edited_cs")
